/* X Language - the eXtensible Language
 * Copyright (C) 2001 Patrick Deschenes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/* These files are distributed at http://www.freesoftware.fsf.org/xlang/
 */

#ifndef __XL_DEFS_H_
#define __XL_DEFS_H_

typedef struct _XLFnct   XLFnct;
typedef struct _XLExpr   XLExpr;
typedef struct _XLData   XLData;
typedef struct _XLType   XLType;
typedef struct _XLClass  XLClass;
typedef struct _XLField  XLField;
typedef struct _XLMeth   XLMeth;
typedef struct _XLDomain XLDomain;
typedef struct _XLGlobal XLGlobal;

#include <xdefs.h>
#include <xobject.h>
#include <xlist.h>
#include <xhash.h>
#include <xstring.h>

#endif
